@@ -5,6 +5,7 @@ import (
 	"encoding/json"
 	"errors"
 	"fmt"
+	"slices"
 	"sort"
 	"unicode"
 
@@ -144,7 +145,7 @@ func createGroupCommitOffsetCmd() *cobra.Command {
 	var offsetMap string
 	var noconfirm bool
 	res := &cobra.Command{
-		Use:   "commit",
+		Use:   "commit GROUP",
 		Short: "Set offset for given consumer group",
 		Long:  "Set offset for a given consumer group, creates one if it does not exist. Offsets cannot be set on a consumer group with active consumers.",
 		Args:  cobra.ExactArgs(1),
@@ -196,7 +197,7 @@ func createGroupCommitOffsetCmd() *cobra.Command {
 						i, err := strconv.ParseInt(offset, 10, 64)
 						if err != nil {
 							// Try oldest/newest/..
-							if offset == "oldest" {
+							if offset == "oldest" || offset == "earliest" {
 								i = sarama.OffsetOldest
 							} else if offset == "newest" || offset == "latest" {
 								i = sarama.OffsetNewest
@@ -244,7 +245,7 @@ func createGroupCommitOffsetCmd() *cobra.Command {
 			}
 			for _, detail := range groupDescs {
 				state := detail.State
-				if state != "Empty" {
+				if !slices.Contains([]string{"Empty", "Dead"}, state) {
 					errorExit("Consumer group %s has active consumers in it, cannot set offset\n", group)
 				}
 			}
@@ -489,7 +490,14 @@ var groupDescribeCmd = &cobra.Command{
 			errorExit("Failed to fetch group offsets: %v\n", err)
 		}
 
-		for topic, partitions := range offsetAndMetadata.Blocks {
+		topics := make([]string, 0, len(offsetAndMetadata.Blocks))
+		for k := range offsetAndMetadata.Blocks {
+			topics = append(topics, k)
+		}
+		sort.Strings(topics)
+
+		for _, topic := range topics {
+			partitions := offsetAndMetadata.Blocks[topic]
 			if len(flagDescribeTopics) > 0 {
 				var found bool
 				for _, topicToShow := range flagDescribeTopics {
